<template>
  <div class="upload-images">
    <el-upload
      :action="action"
      :data="uploadData"
      :on-success="handleImageSuccess"
      :on-remove="handleRemove"
      :before-upload="beforeUpload"
      :file-list="filelist"
      :multiple="true"
      class="upload-demo"
      list-type="picture-card">
      <div slot="tip" class="el-upload__tip">只能上传jpg/png文件，且不超过2M!</div>
      <i slot="default" class="el-icon-plus"></i>
      <div slot="file" slot-scope="{file}">
        <img
          :src="file.url"
          class="el-upload-list__item-thumbnail"
          :alt="staticurl"
          :preview="uploadtype === 'tongueAndFace' ? 0 : 1"
        >
        <label v-if="file.url" class="el-upload-list__item-status-label"><i class="el-icon-upload-success el-icon-check"/></label>
        <span class="el-upload-list__item-actions">
          <span
            class="el-upload-list__item-preview"
            @click="handlePicturePreview(file)"
            :ref="'previewEl'+file.url"
          >
            <i class="el-icon-zoom-in"/>
          </span>
          <span
            v-if="!file.disable"
            class="el-upload-list__item-delete"
            @click="handleRemove(file)"
          >
            <i class="el-icon-delete"/>
          </span>
        </span>
      </div>
    </el-upload>
  </div>
</template>

<script>
module.exports = {
  name: 'ImagesUpload',
  props: {
    filelist: {
      type: Array,
      default: () => []
    },
    status: {
      type: Number,
      default: 2000
    },
    staticurl: {
      type: String,
      default: ''
    },
    tip: {
      type: String,
      default: ''
    },
    uploadtype: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      action: 'https://upload-z1.qiniup.com',
      uploadData: {
        token: '',
        key: ''
      },
      previewImgList: [],
      previewInitialIndex: 0,
      showViewer: false, // 显示查看器,
      dialogVisible:true,
      filelistObj: []
    }
  },
  created() {},
  methods: {
    uuid() {
      var s = [];
      var hexDigits = "0123456789abcdef";
      for (var i = 0; i < 36; i++) {
          s[i] = hexDigits.substr(Math.floor(Math.random() * 0x10), 1);
      }
      s[14] = "4";  // bits 12-15 of the time_hi_and_version field to 0010
      s[19] = hexDigits.substr((s[19] & 0x3) | 0x8, 1);  // bits 6-7 of the clock_seq_hi_and_reserved to 01
      s[8] = s[13] = s[18] = s[23] = "-";
  
      var uuid = s.join("");
      return uuid;
    },
    funcChina(val){
      if (/.*[\u4e00-\u9fa5]+.*$/.test(val)){
          return false ;
      } else {
          return true ;
      }
    },
    beforeUpload(file) {
      const point = file.name.lastIndexOf('.')
      const suffix = file.name.substr(point)
      const fileName = this.funcChina(file.name.substr(0, point))?file.name.substr(0, point):this.uuid();
      const date = moment().format('YYYYMMDD')
      const fileNames = `images_${fileName}_${date}_${this.guid()}${suffix}`
      this.uploadData.token = getQiniuToken()
      this.uploadData.key = fileNames
    },
    handleImageSuccess(file) {
      const url = 'https://images.dayiketang.com/' + file.key
      this.filelist.push({
        url: url,
        disable: false
      })
      console.log(this.uploadtype,'this.uploadType')
      ibox.handleUpdateImgsList(url, this.uploadtype, 'add');
    },
    handleRemove(file) {
      this.filelist.forEach((item, index) => {
        if (item.url === file.url) {
          this.filelist.splice(index, 1)
        }
      })
      ibox.handleUpdateImgsList(file.url, this.uploadtype, 'remove');
    },
    handlePicturePreview(file) {
      $(this.$refs['previewEl'+file.url]).parents('.el-upload-list__item').find('img').click()
    },
    handleExceed(files, fileList) {
      this.$message.warning(
        `当前限制选择 3 个文件，本次选择了 ${
          files.length
        } 个文件，共选择了 ${files.length + fileList.length} 个文件`
      )
    },
    guid() {
      function S4() {
        return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1)
      }
      return (S4() + S4() + '-' + S4() + '-' + S4() + '-' + S4() + '-' + S4() + S4() + S4())
    },
  }
}
</script>
<style>
.upload-images .el-upload--picture-card {
  line-height: 158px;
}
.upload-images .el-upload-list--picture .el-upload-list__item {
  width: 209px;
  float: left;
  margin-right: 20px;
}
.el-icon-plus>*{
  display: none;
}
.upload-images>.el-icon-plus{
  display: none;
}
.el-upload{
  position: relative;
}
.el-upload>.el-upload__input{
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  opacity: 0;
  display: none;
}
/* .upload-images .el-upload-list__item:hover .el-icon-zoom-in{
  display: none;
} */

/* .upload-images .el-icon-upload-success {
  display: none;
} */

.el-upload__tip {
  display: block;
}
.el-upload-list__item-actions>.el-icon-zoom-in::before{
  content: '';
}
.el-upload-list__item-actions>.el-icon-zoom-in>.el-icon-delete::before{
  content: '';
}
.el-upload.el-upload--picture-card>.el-icon-upload-success.el-icon-check{
  display: none;
}
.upload-images>.el-icon-upload-success.el-icon-check{
  display: none;
}
.el-upload-list__item.is-success img{
  width: 148px;
  height: 148px;
  object-fit: cover;
}
</style>
